@@ -81,11 +81,30 @@ install() {
 		inst_simple "${moddir}/zfs-env-bootfs.service" "${systemdsystemunitdir}/zfs-env-bootfs.service"
 		systemctl -q --root "${initdir}" add-wants zfs-import.target zfs-env-bootfs.service
 
+		# Add user-provided unit overrides:
+		# - /etc/systemd/system/${_service}
+		# - /etc/systemd/system/${_service}.d/overrides.conf
+		# -H ensures they are marked host-only
+		# -o ensures there is no error upon absence of these files
+		inst_multiple -o -H \
+			"${systemdsystemconfdir}/zfs-import.target" \
+			"${systemdsystemconfdir}/zfs-import.target.d/"*.conf
+
 		for _service in \
 			"zfs-import-scan.service" \
 			"zfs-import-cache.service"; do
 			inst_simple "${systemdsystemunitdir}/${_service}"
 			systemctl -q --root "${initdir}" add-wants zfs-import.target "${_service}"
+
+			# Add user-provided unit overrides:
+			# - /etc/systemd/system/${_service}
+			# - /etc/systemd/system/${_service}.d/overrides.conf
+			# -H ensures they are marked host-only
+			# -o ensures there is no error upon absence of these files
+			inst_multiple -o -H \
+				"${systemdsystemconfdir}/${_service}" \
+				"${systemdsystemconfdir}/${_service}.d/"*.conf
+
 		done
 
 		for _service in \
@@ -93,6 +112,15 @@ install() {
 			"zfs-rollback-bootfs.service"; do
 			inst_simple "${moddir}/${_service}" "${systemdsystemunitdir}/${_service}"
 			systemctl -q --root "${initdir}" add-wants initrd.target "${_service}"
+
+			# Add user-provided unit overrides:
+			# - /etc/systemd/system/${_service}
+			# - /etc/systemd/system/${_service}.d/overrides.conf
+			# -H ensures they are marked host-only
+			# -o ensures there is no error upon absence of these files
+			inst_multiple -o -H \
+				"${systemdsystemconfdir}/${_service}" \
+				"${systemdsystemconfdir}/${_service}.d/"*.conf
 		done
 
 		inst_simple "${moddir}/import-opts-generator.sh" "${systemdutildir}/system-environment-generators/zfs-import-opts.sh"
